lcvtoolbox.vision.image.TilingConfig
====================================

.. currentmodule:: lcvtoolbox.vision.image

.. autoclass:: TilingConfig
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TilingConfig.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TilingConfig.max_tiles_per_image
      ~TilingConfig.min_coverage_ratio
      ~TilingConfig.min_tile_size
      ~TilingConfig.output_format
      ~TilingConfig.overlap_percent
      ~TilingConfig.padding_strategy
      ~TilingConfig.preserve_aspect_ratio
      ~TilingConfig.quality
      ~TilingConfig.tile_size
      ~TilingConfig.tiling_strategy
   
   